@@ -71,6 +71,10 @@ Puppet::Type.newtype(:ini_setting) do
   newproperty(:value) do
     desc 'The value of the setting to be defined.'
 
+    munge do |value|
+      value.to_s
+    end
+
     def should_to_s(newvalue)
       if (@resource[:show_diff] == :true && Puppet[:show_diff]) then
         return newvalue
@@ -84,6 +88,15 @@ Puppet::Type.newtype(:ini_setting) do
     def is_to_s(value)
       should_to_s(value)
     end
+
+    def insync?(current)
+      if (@resource[:refreshonly]) then
+        true
+      else
+        current == should
+      end
+    end
+
   end
 
   newparam(:section_prefix) do
@@ -98,4 +111,18 @@ Puppet::Type.newtype(:ini_setting) do
     defaultto(']')
   end
 
+  newparam(:refreshonly) do
+    desc 'A flag indicating whether or not the ini_setting should be updated '+
+         'only when called as part of a refresh event'
+    defaultto false
+    newvalues(true,false)
+  end
+
+  def refresh
+    if self[:refreshonly] then
+      # update the value in the provider, which will save the value to the ini file
+      provider.value = self[:value]
+    end
+  end
+
 end
