@@ -15,7 +15,7 @@ describe provider_class do
   } }
 
   def validate_file(expected_content,tmpfile = tmpfile)
-    File.read(tmpfile).should == expected_content
+    expect(File.read(tmpfile)).to eq(expected_content)
   end
 
 
@@ -48,7 +48,7 @@ describe provider_class do
           end
         end
         child_one.stubs(:file_path).returns(emptyfile)
-        child_one.instances.should == []
+        expect(child_one.instances).to eq([])
       end
       it 'should override the provider instances file_path' do
         child_two = Class.new(provider_class) do
@@ -58,7 +58,7 @@ describe provider_class do
         end
         resource = Puppet::Type::Ini_setting.new(common_params)
         provider = child_two.new(resource)
-        provider.file_path.should == '/some/file/path'
+        expect(provider.file_path).to eq('/some/file/path')
       end
       context 'when file has contecnts' do
         let(:orig_content) {
@@ -89,7 +89,7 @@ subby=bar
             end
           end
           child_three.stubs(:file_path).returns(tmpfile)
-          child_three.instances.size.should eq(7)
+          expect(child_three.instances.size).to eq(7)
           expected_array = [
             {:name => 'section1/foo', :value => 'foovalue' },
             {:name => 'section1/bar', :value => 'barvalue' },
@@ -107,8 +107,8 @@ subby=bar
             ensure_array.push(ensure_value)
             real_array.push(prop_hash)
           end
-          ensure_array.uniq.should eq([:present])
-          ((real_array - expected_array) && (expected_array - real_array)).should == []
+          expect(ensure_array.uniq).to eq([:present])
+          expect(((real_array - expected_array) && (expected_array - real_array))).to eq([])
 
         end
 
@@ -147,9 +147,9 @@ subby=bar
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :setting => 'yahoo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should be false
+      expect(provider.exists?).to be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -171,7 +171,7 @@ subby=bar
 -nonstandard-
   shoes = purple
       EOS
-)
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a missing setting to the correct section with pre/suffix" do
@@ -180,9 +180,9 @@ subby=bar
           :setting => 'yahoo', :value => 'yippee',
           :section_prefix => '-', :section_suffix => '-'))
       provider = described_class.new(resource)
-      provider.exists?.should be false
+      expect(provider.exists?).to be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -204,16 +204,16 @@ subby=bar
   shoes = purple
   yahoo = yippee
       EOS
-)
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a missing setting to the correct section with colon" do
       resource = Puppet::Type::Ini_setting.new(common_params.merge(
           :section => 'section:sub', :setting => 'yahoo', :value => 'yippee'))
       provider = described_class.new(resource)
-      provider.exists?.should be false
+      expect(provider.exists?).to be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -235,7 +235,7 @@ subby=bar
   shoes = purple
 yahoo = yippee
       EOS
-)
+      validate_file(expected_content, tmpfile)
     end
 
     it "should modify an existing setting with a different value" do
@@ -244,7 +244,7 @@ yahoo = yippee
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.value=('bazvalue2')
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -265,7 +265,38 @@ subby=bar
 -nonstandard-
   shoes = purple
       EOS
-      )
+      validate_file(expected_content, tmpfile)
+    end
+
+    it "should modify an existing setting with a different boolean value" do
+      resource = Puppet::Type::Ini_setting.new(common_params.merge(
+        :section => 'section1', :setting => 'master', :value => false))
+      provider = described_class.new(resource)
+      provider.exists?.should be true
+      transaction = double('transaction', :persistence => true)
+      expect(Puppet::Transaction::ResourceHarness.new(transaction).evaluate(provider.resource).out_of_sync).to eq(true)
+      expected_content = <<-EOS
+# This is a comment
+[section1]
+; This is also a comment
+foo=foovalue
+
+bar = barvalue
+master = false
+[section2]
+
+foo= foovalue2
+baz=bazvalue
+url = http://192.168.1.1:8080
+[section:sub]
+subby=bar
+    #another comment
+ ; yet another comment
+
+-nonstandard-
+  shoes = purple
+      EOS
+      validate_file(expected_content, tmpfile)
     end
 
     it "should modify an existing setting with pre/suffix with a different value" do
@@ -276,7 +307,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.value=('orange')
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -297,7 +328,7 @@ subby=bar
 -nonstandard-
   shoes = orange
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should modify an existing setting with a different value - with colon in section" do
@@ -307,7 +338,7 @@ subby=bar
       provider.exists?.should be true
       provider.value.should eq('bar')
       provider.value=('foo')
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -328,7 +359,7 @@ subby=foo
 -nonstandard-
   shoes = purple
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should be able to handle settings with non alphanumbering settings " do
@@ -338,8 +369,7 @@ subby=foo
       provider.exists?.should be true
       provider.value.should eq('http://192.168.1.1:8080')
       provider.value=('http://192.168.0.1:8080')
-
-      validate_file( <<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -360,7 +390,7 @@ subby=bar
 -nonstandard-
   shoes = purple
     EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should be able to handle settings with pre/suffix with non alphanumbering settings " do
@@ -372,8 +402,7 @@ subby=bar
       provider.exists?.should be true
       provider.value.should eq('purple')
       provider.value=('http://192.168.0.1:8080')
-
-      validate_file( <<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -394,7 +423,7 @@ subby=bar
 -nonstandard-
   shoes = http://192.168.0.1:8080
     EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should recognize an existing setting with the specified value" do
@@ -419,7 +448,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -443,7 +472,7 @@ subby=bar
 [section3]
 huzzah = shazaam
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new section with pre/suffix if the section does not exist" do
@@ -453,7 +482,7 @@ huzzah = shazaam
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -477,7 +506,7 @@ subby=bar
 -section3-
 huzzah = shazaam
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new section if the section does not exist - with colon" do
@@ -486,7 +515,7 @@ huzzah = shazaam
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -510,7 +539,7 @@ subby=bar
 [section:subsection]
 huzzah = shazaam
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new section with pre/suffix if the section does not exist - with colon" do
@@ -520,7 +549,7 @@ huzzah = shazaam
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 [section1]
 ; This is also a comment
@@ -544,7 +573,7 @@ subby=bar
 -section:subsection-
 huzzah = shazaam
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new section if no sections exists" do
@@ -624,7 +653,7 @@ foo = http://192.168.1.1:8080
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 foo=blah
 bar = yippee
@@ -632,7 +661,7 @@ bar = yippee
 foo = http://192.168.1.1:8080
  ; yet another comment
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should modify an existing setting with a different value" do
@@ -642,14 +671,14 @@ foo = http://192.168.1.1:8080
       provider.exists?.should be true
       provider.value.should eq('blah')
       provider.value=('yippee')
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
 foo=yippee
 [section2]
 foo = http://192.168.1.1:8080
  ; yet another comment
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should recognize an existing setting with the specified value" do
@@ -674,13 +703,13 @@ foo = http://192.168.1.1:8080
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 foo = yippee
 
 [section2]
 foo = http://192.168.1.1:8080
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should modify an existing setting" do
@@ -690,11 +719,11 @@ foo = http://192.168.1.1:8080
       provider.exists?.should be true
       provider.value.should eq('http://192.168.1.1:8080')
       provider.value=('yippee')
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section2]
 foo = yippee
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new setting" do
@@ -703,12 +732,12 @@ foo = yippee
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section2]
 foo = http://192.168.1.1:8080
 bar = baz
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
   end
 
@@ -730,11 +759,11 @@ foo=bar
       provider.exists?.should be true
       provider.value.should eq('bar')
       provider.value=('yippee')
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section2]
 foo=yippee
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
   end
@@ -757,11 +786,11 @@ foo: bar
       provider.exists?.should be true
       provider.value.should eq('bar')
       provider.value=('yippee')
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section2]
 foo: yippee
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new setting" do
@@ -773,12 +802,12 @@ foo: yippee
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section2]
 foo: bar
 bar: baz
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
   end
@@ -801,11 +830,11 @@ foo bar
       provider.exists?.should be true
       provider.value.should eq('bar')
       provider.value=('yippee')
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section2]
 foo yippee
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new setting" do
@@ -817,12 +846,12 @@ foo yippee
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section2]
 foo bar
 bar baz
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
   end
 
@@ -861,7 +890,7 @@ EOS
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.destroy
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section1]
 ; This is also a comment
 
@@ -884,8 +913,8 @@ subby=bar
 
  -nonstandard-
    shoes = purple
-EOS
-    )
+      EOS
+      validate_file(expected_content, tmpfile)
     end
 
     it "should remove a setting with pre/suffix that exists" do
@@ -895,7 +924,7 @@ EOS
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.destroy
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section1]
 ; This is also a comment
 foo=foovalue
@@ -917,8 +946,8 @@ subby=bar
     #another comment
  ; yet another comment
 
-EOS
-    )
+    EOS
+    validate_file(expected_content, tmpfile)
     end
 
     it "should do nothing for a setting that does not exist" do
@@ -927,7 +956,7 @@ EOS
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.destroy
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section1]
 ; This is also a comment
 foo=foovalue
@@ -952,7 +981,7 @@ subby=bar
  -nonstandard-
    shoes = purple
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should do nothing for a setting with pre/suffix that does not exist" do
@@ -962,7 +991,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.destroy
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section1]
 ; This is also a comment
 foo=foovalue
@@ -987,7 +1016,7 @@ subby=bar
  -nonstandard-
    shoes = purple
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "does not remove a section when the last uncommented setting is removed if there are comments" do
@@ -999,7 +1028,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.destroy
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section1]
 ; This is also a comment
 foo=foovalue
@@ -1023,7 +1052,7 @@ subby=bar
  -nonstandard-
    shoes = purple
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "removes the section when removing the last line in the section" do
@@ -1035,7 +1064,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.destroy
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [section1]
 ; This is also a comment
 foo=foovalue
@@ -1058,7 +1087,7 @@ subby=bar
  -nonstandard-
    shoes = purple
       EOS
-                   )
+      validate_file(expected_content, tmpfile)
     end
   end
 
@@ -1091,7 +1120,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
      [section1]
      ; This is also a comment
@@ -1111,7 +1140,7 @@ subby=bar
   fleezy = flam
  ; yet another comment
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should update an existing setting at the correct indentation when the header is aligned" do
@@ -1120,7 +1149,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
      [section1]
      ; This is also a comment
@@ -1139,7 +1168,7 @@ subby=bar
   fleezy = flam
  ; yet another comment
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a missing setting at the correct indentation when the header is not aligned" do
@@ -1148,7 +1177,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
      [section1]
      ; This is also a comment
@@ -1168,7 +1197,7 @@ subby=bar
   fleezy = flam
  ; yet another comment
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should update an existing setting at the correct indentation when the header is not aligned" do
@@ -1177,7 +1206,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
      [section1]
      ; This is also a comment
@@ -1196,7 +1225,7 @@ subby=bar
   fleezy = flam
  ; yet another comment
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a missing setting at the min indentation when the section is not aligned" do
@@ -1205,7 +1234,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
      [section1]
      ; This is also a comment
@@ -1225,7 +1254,7 @@ subby=bar
  ; yet another comment
  yahoo = yippee
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should update an existing setting at the previous indentation when the section is not aligned" do
@@ -1234,7 +1263,7 @@ subby=bar
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 # This is a comment
      [section1]
      ; This is also a comment
@@ -1253,7 +1282,7 @@ subby=bar
   fleezy = flam2
  ; yet another comment
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
   end
@@ -1281,7 +1310,7 @@ blah = blah
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
      [section1]
      # foo=foovalue
      bar=barvalue
@@ -1294,7 +1323,7 @@ foo = foo3
 blah = blah
 #baz=
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should update an existing setting in place, even if there is a commented version of that setting" do
@@ -1303,7 +1332,7 @@ blah = blah
       provider = described_class.new(resource)
       provider.exists?.should be true
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
      [section1]
      # foo=foovalue
      bar=barvalue
@@ -1315,7 +1344,7 @@ blah = blah
 blah = blah
 #baz=
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new setting below a commented version of that setting, respecting semicolons as comments" do
@@ -1324,7 +1353,7 @@ blah = blah
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
      [section1]
      # foo=foovalue
      bar=barvalue
@@ -1337,7 +1366,7 @@ bar=bar3
 blah = blah
 #baz=
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     it "should add a new setting below an empty commented version of that setting" do
@@ -1346,7 +1375,7 @@ blah = blah
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
      [section1]
      # foo=foovalue
      bar=barvalue
@@ -1359,7 +1388,7 @@ blah = blah
 #baz=
 baz=bazvalue
       EOS
-      )
+      validate_file(expected_content, tmpfile)
     end
 
     context 'when a section only contains comments' do
@@ -1370,6 +1399,7 @@ baz=bazvalue
 # bar=bar2
 EOS
     }
+
       it 'should be able to add a new setting when a section contains only comments' do
         resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section1', :setting => 'foo', :value => 'foovalue2')
@@ -1377,14 +1407,15 @@ EOS
         provider = described_class.new(resource)
         provider.exists?.should be false
         provider.create
-        validate_file(<<-EOS
+        expected_content = <<-EOS
 [section1]
 # foo=foovalue
 foo=foovalue2
 # bar=bar2
         EOS
-        )
+        validate_file(expected_content, tmpfile)
       end
+
       it 'should be able to add a new setting when it matches a commented out line other than the first one' do
         resource = Puppet::Type::Ini_setting.new(
           common_params.merge(:section => 'section1', :setting => 'bar', :value => 'barvalue2')
@@ -1392,13 +1423,13 @@ foo=foovalue2
         provider = described_class.new(resource)
         provider.exists?.should be false
         provider.create
-        validate_file(<<-EOS
+        expected_content = <<-EOS
 [section1]
 # foo=foovalue
 # bar=bar2
 bar=barvalue2
         EOS
-        )
+        validate_file(expected_content, tmpfile)
       end
     end
 
@@ -1430,7 +1461,7 @@ subby=bar
         provider = described_class.new(resource)
         provider.exists?.should be false
         provider.create
-        validate_file(<<-EOS
+        expected_content = <<-EOS
 # This is a comment
 [section - one]
 ; This is also a comment
@@ -1449,7 +1480,7 @@ subby=bar
     #another comment
  ; yet another comment
         EOS
-  )
+        validate_file(expected_content, tmpfile)
       end
 
     end
@@ -1480,7 +1511,7 @@ to-deploy = log --merges --grep='pull request' --format='%s (%cN)' origin/produc
       provider = described_class.new(resource)
       provider.exists?.should be false
       provider.create
-      validate_file(<<-EOS
+      expected_content = <<-EOS
 [branch "master"]
         remote = origin
         merge = refs/heads/master
@@ -1491,8 +1522,8 @@ foo = bar
 [branch "production"]
         remote = origin
         merge = refs/heads/production
-                    EOS
-                   )
+      EOS
+      validate_file(expected_content, tmpfile)
     end
   end
 end
